@@ -11,7 +11,7 @@
 # URL        : https://github.com/john-james-ai/studioai                                           #
 # ------------------------------------------------------------------------------------------------ #
 # Created    : Thursday August 10th 2023 08:29:08 pm                                               #
-# Modified   : Monday August 28th 2023 06:14:36 am                                                 #
+# Modified   : Monday August 28th 2023 04:15:32 pm                                                 #
 # ------------------------------------------------------------------------------------------------ #
 # License    : MIT License                                                                         #
 # Copyright  : (c) 2023 John James                                                                 #
@@ -26,7 +26,7 @@ import pandas as pd
 
 from studioai.stats.descriptive.summary import SummaryStats
 from studioai.visual.base import Visualizer
-from studioai.container import VisualizerContainer
+from studioai.visual.container import VisualizerContainer
 
 # ------------------------------------------------------------------------------------------------ #
 logger = logging.getLogger(__name__)
@@ -67,6 +67,7 @@ class Dataset(ABC):
         """Returns the count of data types in the dataset."""
         dtypes = self._df.dtypes.value_counts().reset_index()
         dtypes.columns = ["Data Type", "Count"]
+        dtypes = dtypes.groupby(by="Data Type").sum()
         return dtypes
 
     @property
@@ -281,7 +282,7 @@ class Dataset(ABC):
     # ------------------------------------------------------------------------------------------- #
     def _format(self, df: pd.DataFrame) -> pd.DataFrame:
         """Returns the resulting dataframe with capitalized column names."""
-        df.columns = [col.capitalize() for col in df.columns]
+        # df.columns = [col.capitalize() for col in df.columns]
         df = df.apply(self._show_thousands_separator)
         return df
 
